0.8.0 2015-03-06
----------------

- Add external cover art services.


0.7.1 2015-02-26
----------------

- Minor UI improvements.


0.7.0 2015-02-20
----------------

- Manage multiple server connections in app.

- Prepare for new Mopidy `mixer` API.

- Various UI improvements.


0.6.3 2015-02-12
----------------

- Stability improvements.


0.6.2 2015-02-11
----------------

- Playback time/seek improvements.


0.6.1 2015-02-11
----------------

- Refactor popover menus and handle language change.

- Add `actions` service.


0.6.0 2015-02-10
----------------

- Add `icomoon` icon font.

- Sort playlists by name.

- Add URL to tracklist.

- Error handling.


0.5.1 2015-02-02
----------------

- Configure WebServer URL for use with reverse proxies.

- Bundle `.js` files for faster page loads.

- Use versioned URLs to improve browser caching.


0.5.0 2015-01-30
----------------

- Handle multiple connections in app.

- Implement application logging.


0.4.0 2015-01-29
----------------

- Lookup artist and album search results.

- Merge and sort multiple search results.

- Reload playlists on `event:playlistChanged`.

- Add `debug` setting.

- Add build script for Android app.


0.3.0 2015-01-28
----------------

- Refactor connection service.

- Add ``item-icon-right`` to all collection items.

- CSS cleanup: class names, thumbnail size, menu styles.

- Check for missing resources in `setup.py`.


0.2.2 2015-01-27
----------------

- Change library "add" strategy.


0.2.1 2015-01-27
----------------

- Add missing popovers.


0.2.0 2015-01-27
----------------

- Add connection configuration.

- Fix click in search results.

- Restructure JS source files.

- Various UI improvements/fixes.


0.1.3 2015-01-27
----------------

- Bump version due to PyPi issues.


0.1.2 2015-01-27
----------------

- Fix play/pause toggle button issues.


0.1.1 2015-01-26
----------------

- Fix root search.

- Workaround for play/pause toggle button issues.

- Workaround for reconnect issues.


0.1.0 2015-01-26
----------------

- Initial release.
